package com.example.venue_reservation_service.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.venue_reservation_service.domain.SensitiveWord;
import com.example.venue_reservation_service.dto.PageDTO;
import com.example.venue_reservation_service.dto.SensitiveWordDTO;
import com.example.venue_reservation_service.mapper.SensitiveWordMapper;
import com.example.venue_reservation_service.service.SensitiveWordService;
import com.example.venue_reservation_service.vo.QueryVO;
import com.example.venue_reservation_service.vo.Result;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.time.LocalDateTime;

/**
 * 敏感词业务实现类
 */
@Service
public class SensitiveWordServiceImpl extends ServiceImpl<SensitiveWordMapper, SensitiveWord> implements SensitiveWordService {

    @Resource
    private SensitiveWordMapper sensitiveWordMapper;

    /**
     * 分页查询敏感词列表
     */
    @Override
    public Result getSensitiveWords(PageDTO dto) {
        Page<SensitiveWord> page = new Page<>(dto.getCurrent(), dto.getSize());
        page = page(page, null);
        QueryVO<SensitiveWord> vo = new QueryVO<>();
        vo.setList(page.getRecords());
        vo.setTotal(page.getTotal());
        return Result.ok(vo).message("查询成功");
    }

    /**
     * 添加敏感词
     */
    @Override
    public Result addSensitiveWord(SensitiveWordDTO sensitiveWordDTO) {
        // 去空格后判断是否重复
        String word = sensitiveWordDTO.getWord().trim();
        if (count(new LambdaQueryWrapper<SensitiveWord>().eq(SensitiveWord::getWord, word)) > 0) {
            return Result.fail().message("该敏感词已存在");
        }

        SensitiveWord sensitiveWord = new SensitiveWord();
        sensitiveWord.setWord(word);
        sensitiveWord.setLevel(sensitiveWordDTO.getLevel());
        sensitiveWord.setStatus("0"); // 默认不启用
        sensitiveWord.setCreateTime(LocalDateTime.now());
        sensitiveWord.setUpdateTime(LocalDateTime.now());
        save(sensitiveWord);

        return Result.ok().message("添加成功");
    }


    /**
     * 修改敏感词信息
     */
    @Override
    public Result updateSensitiveWord(Integer id, SensitiveWordDTO sensitiveWordDTO) {
        SensitiveWord sensitiveWord = getById(id);
        if (sensitiveWord == null) {
            return Result.fail().message("未找到对应敏感词");
        }

        sensitiveWord.setWord(sensitiveWordDTO.getWord().trim());
        sensitiveWord.setLevel(sensitiveWordDTO.getLevel());

        updateById(sensitiveWord);
        return Result.ok().message("修改成功");
    }

    /**
     * 删除敏感词
     */
    @Override
    public Result removeSensitiveWord(Integer id) {
        if (!exists(id)) {
            return Result.fail().message("未找到对应敏感词");
        }
        removeById(id);
        return Result.ok().message("删除成功");
    }

    // 辅助方法：检查是否存在
    private boolean exists(Integer id) {
        return count(new LambdaQueryWrapper<SensitiveWord>().eq(SensitiveWord::getId, id)) > 0;
    }
}
